@@ -5,6 +5,7 @@
 #' fitted values of the model.
 #'
 #' @param model An object of class \code{lm}.
+#' @param print_plot logical; if \code{TRUE}, prints the plot else returns a plot object.
 #'
 #' @details
 #' Cook's distance was introduced by American statistician R Dennis Cook in
@@ -25,7 +26,7 @@
 #' @return \code{ols_plot_cooksd_chart} returns  a list containing the
 #' following components:
 #'
-#' \item{outliers}{a tibble with observation number and \code{cooks distance} that exceed \code{threshold}}
+#' \item{outliers}{a \code{data.frame} with observation number and \code{cooks distance} that exceed \code{threshold}}
 #' \item{threshold}{\code{threshold} for classifying an observation as an outlier}
 #'
 #' @section Deprecated Function:
@@ -41,7 +42,7 @@
 #'
 #' @export
 #'
-ols_plot_cooksd_chart <- function(model) {
+ols_plot_cooksd_chart <- function(model, print_plot = TRUE) {
 
   check_model(model)
 
@@ -66,9 +67,11 @@ ols_plot_cooksd_chart <- function(model) {
       label = paste("Threshold:", round(k$ts, 3))
     )
 
-  suppressWarnings(print(p))
-  result <- list(outliers = f, threshold = k$ts, plot = p)
-  invisible(result)
+  if (print_plot) {
+    suppressWarnings(print(p))
+  } else {
+    return(list(plot = p, outliers = f, threshold = k$ts))
+  }
 
 }
 
