@@ -3,6 +3,7 @@
 #' Panel of plots to detect influential observations using DFBETAs.
 #'
 #' @param model An object of class \code{lm}.
+#' @param print_plot logical; if \code{TRUE}, prints the plot else returns a plot object.
 #'
 #' @details
 #' DFBETA measures the difference in each parameter estimate with and without
@@ -13,7 +14,7 @@
 #' general cutoff value to indicate influential observations and
 #' \eqn{2/\sqrt(n)} as a size-adjusted cutoff.
 #'
-#' @return list; \code{ols_plot_dfbetas} returns a list of tibbles (for intercept and each predictor)
+#' @return list; \code{ols_plot_dfbetas} returns a list of \code{data.frame} (for intercept and each predictor)
 #' with the observation number and DFBETA of observations that exceed the threshold for classifying
 #' an observation as an outlier/influential observation.
 #'
@@ -37,7 +38,7 @@
 #'
 #' @export
 #'
-ols_plot_dfbetas <- function(model) {
+ols_plot_dfbetas <- function(model, print_plot = TRUE) {
 
   check_model(model)
 
@@ -55,7 +56,7 @@ ols_plot_dfbetas <- function(model) {
   for (i in seq_len(np)) {
 
     dbetas  <- dfb[, i]
-    df_data <- tibble(obs = seq_len(n), dbetas = dbetas)
+    df_data <- data.frame(obs = seq_len(n), dbetas = dbetas)
     d       <- ols_prep_dfbeta_data(df_data, threshold)
     f       <- ols_prep_dfbeta_outliers(d)
 
@@ -81,8 +82,11 @@ ols_plot_dfbetas <- function(model) {
 
   }
 
-  plots <- marrangeGrob(myplots, nrow = 2, ncol = 2)
-  plots
+  if (print_plot) {
+    marrangeGrob(myplots, nrow = 2, ncol = 2)
+  } else {
+    return(list(plots = myplots, outliers = outliers))
+  }
 
 }
 
