@@ -6,8 +6,9 @@
 #' you should consider adding the new predictor to the model.
 #'
 #' @param model An object of class \code{lm}.
-#' @param data A \code{dataframe} or \code{tibble}.
+#' @param data A \code{data.frame} or \code{tibble}.
 #' @param variable Character; new predictor to be added to the \code{model}.
+#' @param print_plot logical; if \code{TRUE}, prints the plot else returns a plot object.
 #'
 #' @examples
 #' model <- lm(mpg ~ disp + hp + wt, data = mtcars)
@@ -15,30 +16,31 @@
 #'
 #' @export
 #'
-rvsr_plot_shiny <- function(model, data, variable) {
+rvsr_plot_shiny <- function(model, data, variable, print_plot = TRUE) {
 
   check_model(model)
-  check_data(data)
 
-  x <- NULL
-  y <- NULL
-  d <- ols_prep_rvsrplot_data(model)
-  v <- l(deparse(substitute(variable)))
-
-  xvar <-
-    data %>%
-    select(!! sym(variable))
-
-  k <- data.frame(x = xvar, y = model$residuals)
+  x    <- NULL
+  y    <- NULL
+  d    <- ols_prep_rvsrplot_data(model)
+  v    <- l(deparse(substitute(variable)))
+  xvar <- data[variable]
+  k    <- data.frame(x = xvar, y = model$residuals)
+  
   colnames(k) <- c("x", "y")
 
-  p <- ggplot(k, aes(x = x, y = y)) +
+  p <-
+    ggplot(k, aes(x = x, y = y)) +
     geom_point(shape = 1, colour = "blue") +
     xlab(paste(variable)) + ylab("Residual") +
     ggtitle(paste("Residual vs", variable)) +
     geom_hline(yintercept = 0, colour = "red")
 
+  if (print_plot) {
+    print(p)
+  } else {
+    return(p)
+  }
 
-  print(p)
 }
 
