@@ -3,6 +3,7 @@
 #' Histogram of residuals for detecting violation of normality assumption.
 #'
 #' @param model An object of class \code{lm}.
+#' @param print_plot logical; if \code{TRUE}, prints the plot else returns a plot object.
 #'
 #' @section Deprecated Function:
 #' \code{ols_rsd_hist()} has been deprecated. Instead use \code{ols_plot_resid_hist()}.
@@ -18,25 +19,29 @@
 #'
 #' @export
 #'
-ols_plot_resid_hist <- function(model) {
+ols_plot_resid_hist <- function(model, print_plot = TRUE) {
 
   check_model(model)
 
-  x <- NULL
-  y <- NULL
-
+  x  <- NULL
+  y  <- NULL
   k  <- histdata(model)
   h  <- hist(k$resid, plot = FALSE)
   l  <- histn(k$resid, h)
-  d2 <- tibble(x = l$xfit, y = l$yfit)
-  d  <- tibble(x = k$resid)
+  d2 <- data.frame(x = l$xfit, y = l$yfit)
+  d  <- data.frame(x = k$resid)
 
-  p <- ggplot(d, aes(x = x)) +
+  p <-
+    ggplot(d, aes(x = x)) +
     geom_histogram(bins = 6, color = "black", fill = "#ADD8E6") +
     geom_line(data = d2, aes(x = x, y = y), color = "#0000A0", size = 1.2) +
     xlab("Residuals") + ggtitle("Residual Histogram")
 
-  print(p)
+  if (print_plot) {
+    print(p)
+  } else {
+    return(p)
+  }
 
 }
 
