@@ -9,9 +9,11 @@
 #'   candidate predictor variables.
 #' @param penter p value; variables with p value less than \code{penter} will
 #'   enter into the model
+#' @param progress Logical; if \code{TRUE}, will display variable selection progress.
 #' @param details Logical; if \code{TRUE}, will print the regression result at
 #'   each step.
 #' @param x An object of class \code{ols_step_forward_p}.
+#' @param print_plot logical; if \code{TRUE}, prints the plot else returns a plot object.
 #' @param ... Other arguments.
 #'
 #' @return \code{ols_step_forward_p} returns an object of class \code{"ols_step_forward_p"}.
@@ -53,7 +55,6 @@
 #' k$model
 #'
 #' @importFrom stats qt
-#' @importFrom dplyr full_join
 #' @importFrom car Anova
 #'
 #' @family variable selection procedures
@@ -65,8 +66,12 @@ ols_step_forward_p <- function(model, ...) UseMethod("ols_step_forward_p")
 #' @export
 #' @rdname ols_step_forward_p
 #'
-ols_step_forward_p.default <- function(model, penter = 0.3, details = FALSE, ...) {
-  
+ols_step_forward_p.default <- function(model, penter = 0.3, progress = FALSE, details = FALSE, ...) {
+
+  if (details) {
+    progress <- TRUE
+  }
+
   check_model(model)
   check_logic(details)
   check_values(penter, 0, 1)
@@ -83,7 +88,7 @@ ols_step_forward_p.default <- function(model, penter = 0.3, details = FALSE, ...
   mlen_p   <- length(all_pred)
 
   step     <- 1
-  ppos     <- step 
+  ppos     <- step
   preds    <- c()
   pvals    <- c()
   tvals    <- c()
@@ -93,20 +98,22 @@ ols_step_forward_p.default <- function(model, penter = 0.3, details = FALSE, ...
   bic      <- c()
   cp       <- c()
 
-  cat(format("Forward Selection Method", justify = "left", width = 27), "\n")
-  cat(rep("-", 27), sep = "", "\n\n")
-  cat(format("Candidate Terms:", justify = "left", width = 16), "\n\n")
-  for (i in seq_len(length(nam))) {
-    cat(paste0(i, ". ", nam[i]), "\n")
-  }
-  cat("\n")
+  if (progress) {
+    cat(format("Forward Selection Method", justify = "left", width = 27), "\n")
+    cat(rep("-", 27), sep = "", "\n\n")
+    cat(format("Candidate Terms:", justify = "left", width = 16), "\n\n")
+    for (i in seq_len(length(nam))) {
+      cat(paste0(i, ". ", nam[i]), "\n")
+    }
+    cat("\n")
 
-  cat(crayon::bold$red("We are selecting variables based on p value..."))
-  cat("\n")
+    cat("We are selecting variables based on p value...")
+    cat("\n")
 
-  cat("\n")
-  if (!details) {
-    cat("Variables Entered:", "\n\n")
+    cat("\n")
+    if (!details) {
+      cat("Variables Entered:", "\n\n")
+    }
   }
 
 
@@ -129,18 +136,20 @@ ols_step_forward_p.default <- function(model, penter = 0.3, details = FALSE, ...
   sbic   <- ols_sbic(fr$model, model)
   rmse   <- sqrt(fr$ems)
 
-  if (details == TRUE) {
+  if (details) {
     cat("\n")
     cat(paste("Forward Selection: Step", step), "\n\n")
   }
 
-  if (interactive()) {
-    cat(crayon::green(clisymbols::symbol$tick), crayon::bold(dplyr::last(preds)), "\n")
-  } else {
-    cat(paste("-", dplyr::last(preds)), "\n")
+  if (progress) {
+    if (interactive()) {
+      cat("+", tail(preds, n = 1), "\n")
+    } else {
+      cat(paste("-", tail(preds, n = 1)), "\n")
+    }
   }
 
-  if (details == TRUE) {
+  if (details) {
     cat("\n")
     m <- ols_regress(paste(response, "~", paste(preds, collapse = " + ")), l)
     print(m)
@@ -158,10 +167,9 @@ ols_step_forward_p.default <- function(model, penter = 0.3, details = FALSE, ...
     for (i in seq_len(len_p)) {
 
       predictors <- c(preds, all_pred[i])
-      m <- lm(paste(response, "~",
-                             paste(predictors, collapse = " + ")), l)
-      m_sum <- Anova(m)
-      pvals[i] <- m_sum$`Pr(>F)`[ppos]
+      m          <- lm(paste(response, "~", paste(predictors, collapse = " + ")), l)
+      m_sum      <- Anova(m)
+      pvals[i]   <- m_sum$`Pr(>F)`[ppos]
     }
 
     minp  <- which(pvals == min(pvals, na.rm = TRUE))
@@ -171,8 +179,7 @@ ols_step_forward_p.default <- function(model, penter = 0.3, details = FALSE, ...
       step   <- step + 1
       preds  <- c(preds, all_pred[minp])
       lpreds <- length(preds)
-      fr     <- ols_regress(paste(response, "~",
-                                  paste(preds, collapse = " + ")), l)
+      fr     <- ols_regress(paste(response, "~", paste(preds, collapse = " + ")), l)
       rsq    <- c(rsq, fr$rsq)
       adjrsq <- c(adjrsq, fr$adjr)
       aic    <- c(aic, ols_aic(fr$model))
@@ -181,53 +188,59 @@ ols_step_forward_p.default <- function(model, penter = 0.3, details = FALSE, ...
       cp     <- c(cp, ols_mallows_cp(fr$model, model))
       rmse   <- c(rmse, sqrt(fr$ems))
 
-      if (details == TRUE) {
+      if (details) {
         cat("\n")
         cat(paste("Forward Selection: Step", step), "\n\n")
       }
 
-      if (interactive()) {
-        cat(crayon::green(clisymbols::symbol$tick), crayon::bold(dplyr::last(preds)), "\n")
-      } else {
-        cat(paste("-", dplyr::last(preds)), "\n")
+      if (progress) {
+        if (interactive()) {
+          cat("+", tail(preds, n = 1), "\n")
+        } else {
+          cat(paste("-", tail(preds, n = 1)), "\n")
+        }
       }
 
-      if (details == TRUE) {
+      if (details) {
         cat("\n")
         m <- ols_regress(paste(response, "~", paste(preds, collapse = " + ")), l)
         print(m)
         cat("\n\n")
       }
     } else {
-      cat("\n")
-      cat(crayon::bold$red("No more variables to be added."))
+      if (progress) {
+        cat("\n")
+        cat("No more variables to be added.")
+      }
       break
     }
   }
 
   prsq <- c(rsq[1], diff(rsq))
 
-  if (details == TRUE) {
+  if (details) {
     cat("\n\n")
     cat("Variables Entered:", "\n\n")
     for (i in seq_len(length(preds))) {
-      if (interactive()) {
-        cat(crayon::green(clisymbols::symbol$tick), crayon::bold(preds[i]), "\n")
+      if (details) {
+        cat("+", preds[i], "\n")
       } else {
         cat(paste("+", preds[i]), "\n")
       }
     }
   }
 
-  cat("\n\n")
-  cat("Final Model Output", "\n")
-  cat(rep("-", 18), sep = "", "\n\n")
+  if (progress) {
+    cat("\n\n")
+    cat("Final Model Output", "\n")
+    cat(rep("-", 18), sep = "", "\n\n")
 
-  fi <- ols_regress(
-    paste(response, "~", paste(preds, collapse = " + ")),
-    data = l
-  )
-  print(fi)
+    fi <- ols_regress(
+      paste(response, "~", paste(preds, collapse = " + ")),
+      data = l
+    )
+    print(fi)
+  }
 
   final_model <- lm(paste(response, "~", paste(preds, collapse = " + ")), data = l)
 
@@ -261,19 +274,19 @@ print.ols_step_forward_p <- function(x, ...) {
 #' @export
 #' @rdname ols_step_forward_p
 #'
-plot.ols_step_forward_p <- function(x, model = NA, ...) {
+plot.ols_step_forward_p <- function(x, model = NA, print_plot = TRUE, ...) {
 
   a <- NULL
   b <- NULL
 
   y <- seq_len(length(x$rsquare))
 
-  d1 <- tibble(a = y, b = x$rsquare)
-  d2 <- tibble(a = y, b = x$adjr)
-  d3 <- tibble(a = y, b = x$mallows_cp)
-  d4 <- tibble(a = y, b = x$aic)
-  d5 <- tibble(a = y, b = x$sbic)
-  d6 <- tibble(a = y, b = x$sbc)
+  d1 <- data.frame(a = y, b = x$rsquare)
+  d2 <- data.frame(a = y, b = x$adjr)
+  d3 <- data.frame(a = y, b = x$mallows_cp)
+  d4 <- data.frame(a = y, b = x$aic)
+  d5 <- data.frame(a = y, b = x$sbic)
+  d6 <- data.frame(a = y, b = x$sbc)
 
   p1 <- plot_stepwise(d1, "R-Square")
   p2 <- plot_stepwise(d2, "Adj. R-Square")
@@ -284,8 +297,12 @@ plot.ols_step_forward_p <- function(x, model = NA, ...) {
 
   myplots <- list(plot_1 = p1, plot_2 = p2, plot_3 = p3,
                   plot_4 = p4, plot_5 = p5, plot_6 = p6)
-  result <- marrangeGrob(myplots, nrow = 2, ncol = 2)
-  result
+
+  if (print_plot) {
+    marrangeGrob(myplots, nrow = 2, ncol = 2)
+  } else {
+    return(myplots)
+  }
 
 }
 
