@@ -11,9 +11,11 @@
 #'   into the model.
 #' @param prem p value; variables with p more than \code{prem} will be removed
 #'   from the model.
+#' @param progress Logical; if \code{TRUE}, will display variable selection progress.
 #' @param details Logical; if \code{TRUE}, will print the regression result at
   #' each step.
 #' @param x An object of class \code{ols_step_both_p}.
+#' @param print_plot logical; if \code{TRUE}, prints the plot else returns a plot object.
 #' @param ... Other arguments.
 #' @return \code{ols_step_both_p} returns an object of class \code{"ols_step_both_p"}.
 #' An object of class \code{"ols_step_both_p"} is a list containing the
@@ -61,7 +63,11 @@ ols_step_both_p <- function(model, ...) UseMethod("ols_step_both_p")
 #' @export
 #' @rdname ols_step_both_p
 #'
-ols_step_both_p.default <- function(model, pent = 0.1, prem = 0.3, details = FALSE, ...) {
+ols_step_both_p.default <- function(model, pent = 0.1, prem = 0.3, progress = FALSE, details = FALSE, ...) {
+
+  if (details) {
+    progress <- TRUE
+  }
 
   check_model(model)
   check_logic(details)
@@ -69,12 +75,7 @@ ols_step_both_p.default <- function(model, pent = 0.1, prem = 0.3, details = FAL
   check_values(prem, 0, 1)
   check_npredictors(model, 3)
 
-  response <-
-    model %>%
-    use_series(model) %>%
-    names() %>%
-    extract(1)
-
+  response <- names(model$model)[1]
   l        <- eval(model$call$data)
   nam      <- colnames(attr(model$terms, "factors"))
   df       <- nrow(l) - 2
@@ -99,25 +100,23 @@ ols_step_both_p.default <- function(model, pent = 0.1, prem = 0.3, details = FAL
   f       <- c()
   fp      <- c()
 
+  if (progress) {
+    cat(format("Stepwise Selection Method", justify = "left", width = 27), "\n")
+    cat(rep("-", 27), sep = "", "\n\n")
+    cat(format("Candidate Terms:", justify = "left", width = 16), "\n\n")
+    for (i in seq_len(length(nam))) {
+      cat(paste0(i, ". ", nam[i]), "\n")
+    }
+    cat("\n")
 
+    cat("We are selecting variables based on p value...")
+    cat("\n")
 
-
-  cat(format("Stepwise Selection Method", justify = "left", width = 27), "\n")
-  cat(rep("-", 27), sep = "", "\n\n")
-  cat(format("Candidate Terms:", justify = "left", width = 16), "\n\n")
-  for (i in seq_len(length(nam))) {
-    cat(paste0(i, ". ", nam[i]), "\n")
+    cat("\n")
+    if (!details) {
+      cat("Variables Entered/Removed:", "\n\n")
+    }
   }
-  cat("\n")
-
-  cat(crayon::bold$red("We are selecting variables based on p value..."))
-  cat("\n")
-
-  cat("\n")
-  if (!details) {
-    cat("Variables Entered/Removed:", "\n\n")
-  }
-
 
   for (i in seq_len(mlen_p)) {
     predictors <- all_pred[i]
@@ -144,19 +143,20 @@ ols_step_both_p.default <- function(model, pent = 0.1, prem = 0.3, details = FAL
   lbetas  <- append(lbetas, length(fr$betas))
   pvalues <- append(pvalues, fr$pvalues)
 
-  if (details == TRUE) {
+  if (details) {
     cat("\n")
     cat(paste("Stepwise Selection: Step", step), "\n\n")
   }
 
-  if (interactive()) {
-    cat(crayon::green(clisymbols::symbol$tick), crayon::bold(dplyr::last(preds)), "\n")
-  } else {
-    cat(paste("-", dplyr::last(preds), "added"), "\n")
+  if (progress) {
+    if (interactive()) {
+      cat("+", tail(preds, n = 1), "\n")
+    } else {
+      cat(paste("-", tail(preds, n = 1), "added"), "\n")
+    }
   }
 
-
-  if (details == TRUE) {
+  if (details) {
     cat("\n")
     m <- ols_regress(paste(response, "~", paste(preds, collapse = " + ")), l)
     print(m)
@@ -208,19 +208,20 @@ ols_step_both_p.default <- function(model, pent = 0.1, prem = 0.3, details = FAL
       lbetas    <- append(lbetas, length(fr$betas))
       pvalues   <- append(pvalues, fr$pvalues)
 
-      if (details == TRUE) {
+      if (details) {
         cat("\n")
         cat(paste("Stepwise Selection: Step", step), "\n\n")
       }
 
-      if (interactive()) {
-        cat(crayon::green(clisymbols::symbol$tick), crayon::bold(dplyr::last(preds)), "\n")
-      } else {
-        cat(paste("-", dplyr::last(preds), "added"), "\n")
+      if (progress) {
+        if (interactive()) {
+          cat("+", tail(preds, n = 1), "\n")
+        } else {
+          cat(paste("-", tail(preds, n = 1), "added"), "\n")
+        }
       }
 
-
-      if (details == TRUE) {
+      if (details) {
         cat("\n")
         m <- ols_regress(paste(response, "~", paste(preds, collapse = " + ")), l)
         print(m)
@@ -228,7 +229,7 @@ ols_step_both_p.default <- function(model, pent = 0.1, prem = 0.3, details = FAL
       }
 
 
-      if (details == TRUE) {
+      if (details) {
         cat("\n")
         m <- ols_regress(paste(response, "~", paste(preds, collapse = " + ")), l)
         print(m)
@@ -261,19 +262,20 @@ ols_step_both_p.default <- function(model, pent = 0.1, prem = 0.3, details = FAL
         lbetas    <- append(lbetas, length(fr$betas))
         pvalues   <- append(pvalues, fr$pvalues)
 
-        if (details == TRUE) {
+        if (details) {
           cat("\n")
           cat(paste("Stepwise Selection: Step", all_step), "\n\n")
         }
 
-        if (interactive()) {
-          cat(crayon::red(clisymbols::symbol$cross), crayon::bold(dplyr::last(var_index)), "\n")
-        } else {
-          cat(paste("-", dplyr::last(var_index), "added"), "\n")
+        if (progress) {
+          if (interactive()) {
+            cat("x", tail(var_index, n = 1), "\n")
+          } else {
+            cat(paste("-", tail(var_index, n = 1), "added"), "\n")
+          }
         }
 
-
-        if (details == TRUE) {
+        if (details) {
           cat("\n")
           m <- ols_regress(paste(response, "~", paste(preds, collapse = " + ")), l)
           print(m)
@@ -284,26 +286,30 @@ ols_step_both_p.default <- function(model, pent = 0.1, prem = 0.3, details = FAL
         all_step <- all_step
       }
     } else {
-      cat("\n")
-      cat(crayon::bold$red(glue("No more variables to be added/removed.")))
-      cat("\n")
+      if (progress) {
+        cat("\n")
+        cat("No more variables to be added/removed.")
+        cat("\n")
+      }
       break
     }
   }
 
-  cat("\n\n")
-  cat("Final Model Output", "\n")
-  cat(rep("-", 18), sep = "", "\n\n")
+  if (progress) {
+    cat("\n\n")
+    cat("Final Model Output", "\n")
+    cat(rep("-", 18), sep = "", "\n\n")
 
-  fi <- ols_regress(
-    paste(response, "~", paste(preds, collapse = " + ")),
-    data = l
-  )
-  print(fi)
+    fi <- ols_regress(
+      paste(response, "~", paste(preds, collapse = " + ")),
+      data = l
+    )
+    print(fi)
+  }
 
   final_model <- lm(paste(response, "~", paste(preds, collapse = " + ")), data = l)
 
-  beta_pval <- tibble(
+  beta_pval <- data.frame(
     model     = rep(seq_len(all_step), lbetas),
     predictor = names(betas),
     beta      = betas,
@@ -348,19 +354,19 @@ print.ols_step_both_p <- function(x, ...) {
 #' @export
 #' @rdname ols_step_both_p
 #'
-plot.ols_step_both_p <- function(x, model = NA, ...) {
+plot.ols_step_both_p <- function(x, model = NA, print_plot = TRUE, ...) {
 
   a <- NULL
   b <- NULL
 
   y <- seq_len(x$steps)
 
-  d1 <- tibble(a = y, b = x$rsquare)
-  d2 <- tibble(a = y, b = x$adjr)
-  d3 <- tibble(a = y, b = x$mallows_cp)
-  d4 <- tibble(a = y, b = x$aic)
-  d5 <- tibble(a = y, b = x$sbic)
-  d6 <- tibble(a = y, b = x$sbc)
+  d1 <- data.frame(a = y, b = x$rsquare)
+  d2 <- data.frame(a = y, b = x$adjr)
+  d3 <- data.frame(a = y, b = x$mallows_cp)
+  d4 <- data.frame(a = y, b = x$aic)
+  d5 <- data.frame(a = y, b = x$sbic)
+  d6 <- data.frame(a = y, b = x$sbc)
 
   p1 <- plot_stepwise(d1, "R-Square")
   p2 <- plot_stepwise(d2, "Adj. R-Square")
@@ -371,9 +377,12 @@ plot.ols_step_both_p <- function(x, model = NA, ...) {
 
   myplots <- list(plot_1 = p1, plot_2 = p2, plot_3 = p3,
                   plot_4 = p4, plot_5 = p5, plot_6 = p6)
-  result <- marrangeGrob(myplots, nrow = 2, ncol = 2)
-  result
 
+  if (print_plot) {
+    marrangeGrob(myplots, nrow = 2, ncol = 2)
+  } else {
+    return(myplots)
+  }
 
 }
 
