@@ -7,11 +7,10 @@
 #'
 #' @docType package
 #' @name olsrr
-#' @importFrom dplyr %>%
 NULL
 
 ## quiets concerns of R CMD check re: the .'s that appear in pipelines
 if (getRversion() >= "2.15.1") {
-  utils::globalVariables(c(".", "owner", "repo", "tag_name"
+  utils::globalVariables(c(".", "owner", "repo", "tag_name", "result"
   ))
 }
