@@ -79,3 +79,26 @@ l <- function(x) {
   }
   return(out)
 }
+
+#' @importFrom utils packageVersion menu install.packages
+check_suggests <- function(pkg) {
+  
+  pkg_flag <- tryCatch(utils::packageVersion(pkg), error = function(e) NA)
+  
+  if (is.na(pkg_flag)) {
+    
+    msg <- message(paste0('\n', pkg, ' must be installed for this functionality.'))
+    
+    if (interactive()) {
+      message(msg, "\nWould you like to install it?")
+      if (utils::menu(c("Yes", "No")) == 1) {
+        utils::install.packages(pkg)
+      } else {
+        stop(msg, call. = FALSE)
+      }
+    } else {
+      stop(msg, call. = FALSE)
+    } 
+  }
+
+}
\ No newline at end of file
